@@ -12,6 +12,10 @@ module Puppet::Parser::Functions
     Would result in:
 
       ['1','2','3','4','5','6','7','8','9']
+
+    Note: Since Puppet 4.0 concatenation of arrays and hashes can be done with the + operator.
+
+      ['1','2','3'] + ['4','5','6'] + ['7','8','9']
   DOC
              ) do |arguments|
 
