@@ -19,6 +19,22 @@ module Puppet::Parser::Functions
 
         delete('abracadabra', 'bra')
         Would return: 'acada'
+
+    Note that from Puppet 4.0.0 the minus (-) operator deletes values from arrays and keys from a hash:
+
+        ['a', 'b', 'c', 'b'] - 'b'
+        # would return ['a', 'c']
+
+        {'a'=>1,'b'=>2,'c'=>3} - ['b','c'])
+        # would return {'a' => '1'}
+
+    A global delete from a string can be performed with the regsubst() function:
+
+        'abracadabra'.regsubst(/bra/, '', 'G')
+        # would return 'acada'
+
+    In general, the filter() function can filter out entries from arrays and hashes based on keys and/or values.
+
   DOC
              ) do |arguments|
 
