@@ -12,6 +12,12 @@ module Puppet::Parser::Functions
         difference(["a","b","c"],["b","c","d"])
 
     Would return: ["a"]
+
+    Note: Since Puppet 4 the minus (-) operator in the Puppet language does the same thing:
+
+      ['a', 'b', 'c'] - ['b', 'c', 'd']
+      # would return ['a']
+
     DOC
              ) do |arguments|
 
