@@ -3,7 +3,8 @@
 #
 module Puppet::Parser::Functions
   newfunction(:getvar, :type => :rvalue, :doc => <<-'DOC') do |args|
-    Lookup a variable in a remote namespace.
+    Lookup a variable in a given namespace.
+    Returns undef if variable does not exist.
 
     For example:
 
@@ -15,6 +16,11 @@ module Puppet::Parser::Functions
         $datalocation = 'site::data'
         $bar = getvar("${datalocation}::bar")
         # Equivalent to $bar = $site::data::bar
+
+    Note: from Puppet 6.0.0, the compatible function with the same name in Puppet core
+    will be used instead of this function. The new function also has support for
+    digging into a structured value. See the built-in
+    [`getvar`](https://puppet.com/docs/puppet/latest/function.html#getvar) function
     DOC
 
     unless args.length == 1
@@ -27,7 +33,7 @@ module Puppet::Parser::Functions
         result = lookupvar((args[0]).to_s)
       end
 
-      # avoid relying on incosistent behaviour around ruby return values from catch
+      # avoid relying on inconsistent behaviour around ruby return values from catch
       result
     rescue Puppet::ParseError # rubocop:disable Lint/HandleExceptions : Eat the exception if strict_variables = true is set
     end
