@@ -4,6 +4,9 @@
 module Puppet::Parser::Functions
   newfunction(:size, :type => :rvalue, :doc => <<-DOC
     Returns the number of elements in a string, an array or a hash
+
+    Note that since Puppet 5.4.0, the length() function in Puppet is preferred over this. For versions
+    of Puppet < 5.4.0 use the stdlib length() function.
   DOC
              ) do |arguments|
 
