@@ -11,6 +11,12 @@ module Puppet::Parser::Functions
         suffix(['a','b','c'], 'p')
 
     Will return: ['ap','bp','cp']
+
+    Note that since Puppet 4.0.0 the general way to modify values is in array is by using the map
+    function in Puppet. This example does the same as the example above:
+
+        ['a', 'b', 'c'].map |$x| { "${x}p" }
+
     DOC
              ) do |arguments|
 
