@@ -10,6 +10,13 @@ module Puppet::Parser::Functions
         time()
 
     Will return something like: 1311972653
+
+    Note that since Puppet 4.8.0 the Puppet language has the data types Timestamp (a point in time) and
+    Timespan (a duration). The following example is equivalent to calling time() without
+    any arguments:
+
+        Timestamp()
+
     DOC
              ) do |arguments|
 
