@@ -1,5 +1,8 @@
+#
+# validate_email_address.rb
+#
 module Puppet::Parser::Functions
-  newfunction(:validate_email_address, :doc => <<-ENDHEREDOC
+  newfunction(:validate_email_address, :doc => <<-DOC
     Validate that all values passed are valid email addresses.
     Fail compilation if any value fails this check.
     The following values will pass:
@@ -10,7 +13,7 @@ module Puppet::Parser::Functions
     The following values will fail, causing compilation to abort:
     $some_array = [ 'bad_email@/d/efdf.com' ]
     validate_email_address($some_array)
-    ENDHEREDOC
+    DOC
              ) do |args|
     rescuable_exceptions = [ArgumentError]
 
