@@ -1,7 +1,6 @@
-#! /usr/bin/env ruby -S rspec
 require 'spec_helper_acceptance'
 
-describe 'keys function' do
+describe 'keys function', :if => Puppet::Util::Package.versioncmp(Puppet.version, '5.5.0') < 0 do
   describe 'success' do
     pp = <<-DOC
       $a = {'aaa'=>'bbb','ccc'=>'ddd'}
