@@ -2,17 +2,7 @@ require 'spec_helper_acceptance'
 
 describe 'validate_absolute_path function' do
   describe 'success' do
-    %w[
-      C:/
-      C:\\\\
-      C:\\\\WINDOWS\\\\System32
-      C:/windows/system32
-      X:/foo/bar
-      X:\\\\foo\\\\bar
-      /var/tmp
-      /var/lib/puppet
-      /var/opt/../lib/puppet
-    ].each do |path|
+    ['C:/', 'C:\\\\', 'C:\\\\WINDOWS\\\\System32', 'C:/windows/system32', 'X:/foo/bar', 'X:\\\\foo\\\\bar', '/var/tmp', '/var/lib/puppet', '/var/opt/../lib/puppet'].each do |path|
       pp = <<-DOC
         $one = '#{path}'
         validate_absolute_path($one)
