@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe 'camelcase' do
+describe 'camelcase', :if => Puppet::Util::Package.versioncmp(Puppet.version, '6.0.0') < 0 do
   it { is_expected.not_to eq(nil) }
   it { is_expected.to run.with_params.and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params(100).and_raise_error(Puppet::ParseError) }
@@ -12,6 +12,6 @@ describe 'camelcase' do
   it { is_expected.to run.with_params('_').and_return('') }
   it { is_expected.to run.with_params('').and_return('') }
   it { is_expected.to run.with_params([]).and_return([]) }
-  it { is_expected.to run.with_params(%w[abc aa_bb_cc]).and_return(%w[Abc AaBbCc]) }
+  it { is_expected.to run.with_params(['abc', 'aa_bb_cc']).and_return(['Abc', 'AaBbCc']) }
   it { is_expected.to run.with_params(['abc', 1, 'aa_bb_cc']).and_return(['Abc', 1, 'AaBbCc']) }
 end
