@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe 'chomp' do
+describe 'chomp', :if => Puppet::Util::Package.versioncmp(Puppet.version, '6.0.0') < 0 do
   it { is_expected.not_to eq(nil) }
   it { is_expected.to run.with_params.and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params(1).and_raise_error(Puppet::ParseError) }
@@ -11,12 +11,12 @@ describe 'chomp' do
   it { is_expected.to run.with_params('one').and_return('one') }
   it { is_expected.to run.with_params("one\n").and_return('one') }
   it { is_expected.to run.with_params("one\n\n").and_return("one\n") }
-  it { is_expected.to run.with_params(%W[one\n two three\n]).and_return(%w[one two three]) }
+  it { is_expected.to run.with_params(["one\n", 'two', "three\n"]).and_return(['one', 'two', 'three']) }
 
   it { is_expected.to run.with_params(AlsoString.new('one')).and_return('one') }
   it { is_expected.to run.with_params(AlsoString.new("one\n")).and_return('one') }
   it { is_expected.to run.with_params(AlsoString.new("one\n\n")).and_return("one\n") }
-  it { is_expected.to run.with_params([AlsoString.new("one\n"), AlsoString.new('two'), "three\n"]).and_return(%w[one two three]) }
+  it { is_expected.to run.with_params([AlsoString.new("one\n"), AlsoString.new('two'), "three\n"]).and_return(['one', 'two', 'three']) }
 
   context 'with UTF8 and double byte characters' do
     it { is_expected.to run.with_params("ůťƒ8\n\n").and_return("ůťƒ8\n") }
