@@ -14,13 +14,13 @@ describe 'delete_regex' do
     it { is_expected.to run.with_params([], '').and_return([]) }
     it { is_expected.to run.with_params([], 'two').and_return([]) }
     it { is_expected.to run.with_params(['two'], 'two').and_return([]) }
-    it { is_expected.to run.with_params(%w[two two], 'two').and_return([]) }
-    it { is_expected.to run.with_params(%w[one two three], '^t.*').and_return(['one']) }
-    it { is_expected.to run.with_params(%w[ab b c b], 'b').and_return(%w[ab c]) }
-    it { is_expected.to run.with_params(%w[one two three], 'four').and_return(%w[one two three]) }
-    it { is_expected.to run.with_params(%w[one two three], 'e').and_return(%w[one two three]) }
-    it { is_expected.to run.with_params(%w[one two three], 'two').and_return(%w[one three]) }
-    it { is_expected.to run.with_params(%w[two one two three two], 'two').and_return(%w[one three]) }
+    it { is_expected.to run.with_params(['two', 'two'], 'two').and_return([]) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], '^t.*').and_return(['one']) }
+    it { is_expected.to run.with_params(['ab', 'b', 'c', 'b'], 'b').and_return(['ab', 'c']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'four').and_return(['one', 'two', 'three']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'e').and_return(['one', 'two', 'three']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'two').and_return(['one', 'three']) }
+    it { is_expected.to run.with_params(['two', 'one', 'two', 'three', 'two'], 'two').and_return(['one', 'three']) }
     it { is_expected.to run.with_params(['abracadabra'], 'abr').and_return(['abracadabra']) }
     it { is_expected.to run.with_params(['abracadabra'], '^.*jimbob.*$').and_return(['abracadabra']) }
   end
@@ -36,13 +36,13 @@ describe 'delete_regex' do
     }
     it {
       is_expected.to run \
-        .with_params({ 'key1' => 'value1', 'key2' => 'value2', 'key3' => 'value3' }, %w[key1 key2]) \
+        .with_params({ 'key1' => 'value1', 'key2' => 'value2', 'key3' => 'value3' }, ['key1', 'key2']) \
         .and_return('key3' => 'value3')
     }
   end
 
   it 'leaves the original array intact' do
-    argument1 = %w[one two three]
+    argument1 = ['one', 'two', 'three']
     original1 = argument1.dup
     subject.call([argument1, 'two'])
     expect(argument1).to eq(original1)
