@@ -12,14 +12,14 @@ describe 'delete' do
     it { is_expected.to run.with_params([], '').and_return([]) }
     it { is_expected.to run.with_params([], 'two').and_return([]) }
     it { is_expected.to run.with_params(['two'], 'two').and_return([]) }
-    it { is_expected.to run.with_params(%w[two two], 'two').and_return([]) }
-    it { is_expected.to run.with_params(%w[ab b c b], 'b').and_return(%w[ab c]) }
-    it { is_expected.to run.with_params(%w[one two three], 'four').and_return(%w[one two three]) }
-    it { is_expected.to run.with_params(%w[one two three], 'e').and_return(%w[one two three]) }
-    it { is_expected.to run.with_params(%w[one two three], 'two').and_return(%w[one three]) }
-    it { is_expected.to run.with_params(%w[two one two three two], 'two').and_return(%w[one three]) }
-    it { is_expected.to run.with_params(%w[one two three two], %w[one two]).and_return(['three']) }
-    it { is_expected.to run.with_params(['ồאּẻ', 'ŧẅơ', 'ŧңŗё℮', 'ŧẅơ'], %w[ồאּẻ ŧẅơ]).and_return(['ŧңŗё℮']) }
+    it { is_expected.to run.with_params(['two', 'two'], 'two').and_return([]) }
+    it { is_expected.to run.with_params(['ab', 'b', 'c', 'b'], 'b').and_return(['ab', 'c']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'four').and_return(['one', 'two', 'three']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'e').and_return(['one', 'two', 'three']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three'], 'two').and_return(['one', 'three']) }
+    it { is_expected.to run.with_params(['two', 'one', 'two', 'three', 'two'], 'two').and_return(['one', 'three']) }
+    it { is_expected.to run.with_params(['one', 'two', 'three', 'two'], ['one', 'two']).and_return(['three']) }
+    it { is_expected.to run.with_params(['ồאּẻ', 'ŧẅơ', 'ŧңŗё℮', 'ŧẅơ'], ['ồאּẻ', 'ŧẅơ']).and_return(['ŧңŗё℮']) }
   end
 
   describe 'deleting from a string' do
@@ -30,11 +30,11 @@ describe 'delete' do
     it { is_expected.to run.with_params('barbar', 'bar').and_return('') }
     it { is_expected.to run.with_params('barfoobar', 'bar').and_return('foo') }
     it { is_expected.to run.with_params('foobarbabarz', 'bar').and_return('foobaz') }
-    it { is_expected.to run.with_params('foobarbabarz', %w[foo bar]).and_return('baz') }
-    it { is_expected.to run.with_params('ƒōōβậяβậβậяź', %w[ƒōō βậя]).and_return('βậź') }
+    it { is_expected.to run.with_params('foobarbabarz', ['foo', 'bar']).and_return('baz') }
+    it { is_expected.to run.with_params('ƒōōβậяβậβậяź', ['ƒōō', 'βậя']).and_return('βậź') }
 
-    it { is_expected.to run.with_params('barfoobar', %w[barbar foo]).and_return('barbar') }
-    it { is_expected.to run.with_params('barfoobar', %w[foo barbar]).and_return('') }
+    it { is_expected.to run.with_params('barfoobar', ['barbar', 'foo']).and_return('barbar') }
+    it { is_expected.to run.with_params('barfoobar', ['foo', 'barbar']).and_return('') }
   end
 
   describe 'deleting from an array' do
@@ -48,18 +48,18 @@ describe 'delete' do
     }
     it {
       is_expected.to run \
-        .with_params({ 'key1' => 'value1', 'key2' => 'value2', 'key3' => 'value3' }, %w[key1 key2]) \
+        .with_params({ 'key1' => 'value1', 'key2' => 'value2', 'key3' => 'value3' }, ['key1', 'key2']) \
         .and_return('key3' => 'value3')
     }
     it {
       is_expected.to run \
-        .with_params({ 'ĸəұ1' => 'νãŀủĕ1', 'ĸəұ2' => 'νãŀủĕ2', 'ĸəұ3' => 'νãŀủĕ3' }, %w[ĸəұ1 ĸəұ2]) \
+        .with_params({ 'ĸəұ1' => 'νãŀủĕ1', 'ĸəұ2' => 'νãŀủĕ2', 'ĸəұ3' => 'νãŀủĕ3' }, ['ĸəұ1', 'ĸəұ2']) \
         .and_return('ĸəұ3' => 'νãŀủĕ3')
     }
   end
 
   it 'leaves the original array intact' do
-    argument1 = %w[one two three]
+    argument1 = ['one', 'two', 'three']
     original1 = argument1.dup
     _result = subject.call([argument1, 'two'])
     expect(argument1).to eq(original1)
