@@ -80,11 +80,11 @@ describe 'dig44' do
 
   context 'with structured values' do
     it 'is able to extract a deeply nested hash value' do
-      is_expected.to run.with_params(data, %w[a g], 'default').and_return('2')
+      is_expected.to run.with_params(data, ['a', 'g'], 'default').and_return('2')
     end
 
     it 'returns the default value if the path is too long' do
-      is_expected.to run.with_params(data, %w[a g c d], 'default').and_return('default')
+      is_expected.to run.with_params(data, ['a', 'g', 'c', 'd'], 'default').and_return('default')
     end
 
     it 'supports an array index (number) in the path' do
@@ -92,23 +92,23 @@ describe 'dig44' do
     end
 
     it 'supports an array index (string) in the path' do
-      is_expected.to run.with_params(data, %w[a e 1], 'default').and_return('f1')
+      is_expected.to run.with_params(data, ['a', 'e', '1'], 'default').and_return('f1')
     end
 
     it 'returns the default value if an array index is not a number' do
-      is_expected.to run.with_params(data, %w[a b c], 'default').and_return('default')
+      is_expected.to run.with_params(data, ['a', 'b', 'c'], 'default').and_return('default')
     end
 
     it 'returns the default value if and index is out of array length' do
-      is_expected.to run.with_params(data, %w[a e 5], 'default').and_return('default')
+      is_expected.to run.with_params(data, ['a', 'e', '5'], 'default').and_return('default')
     end
 
     it 'is able to path though both arrays and hashes' do
-      is_expected.to run.with_params(data, %w[a e 2 x y], 'default').and_return('z')
+      is_expected.to run.with_params(data, ['a', 'e', '2', 'x', 'y'], 'default').and_return('z')
     end
 
     it 'returns "nil" if value is not found and no default value is provided' do
-      is_expected.to run.with_params(data, %w[a 1]).and_return(nil)
+      is_expected.to run.with_params(data, ['a', '1']).and_return(nil)
     end
   end
 
