@@ -7,6 +7,9 @@ describe 'dirname' do
   it { is_expected.to run.with_params([]).and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params({}).and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params(1).and_raise_error(Puppet::ParseError) }
+  it { is_expected.to run.with_params('').and_raise_error(Puppet::ParseError) }
+  it { is_expected.to run.with_params(:undef).and_raise_error(Puppet::ParseError) }
+  it { is_expected.to run.with_params(nil).and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params('/path/to/a/file.ext', []).and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params('/path/to/a/file.ext').and_return('/path/to/a') }
   it { is_expected.to run.with_params('relative_path/to/a/file.ext').and_return('relative_path/to/a') }
