@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe 'floor' do
+describe 'floor', :if => Puppet::Util::Package.versioncmp(Puppet.version, '6.0.0') < 0 do
   it { is_expected.not_to eq(nil) }
   it { is_expected.to run.with_params.and_raise_error(Puppet::ParseError) }
   it { is_expected.to run.with_params('foo').and_raise_error(Puppet::ParseError) }
