@@ -9,7 +9,7 @@ describe 'hash' do
   }
   it { is_expected.to run.with_params(['one']).and_raise_error(Puppet::ParseError, %r{Unable to compute}) }
   it { is_expected.to run.with_params([]).and_return({}) }
-  it { is_expected.to run.with_params(%w[key1 value1]).and_return('key1' => 'value1') }
+  it { is_expected.to run.with_params(['key1', 'value1']).and_return('key1' => 'value1') }
   it { is_expected.to run.with_params(['κ℮ұ1', '√āĺűẻ1']).and_return('κ℮ұ1' => '√āĺűẻ1') }
-  it { is_expected.to run.with_params(%w[key1 value1 key2 value2]).and_return('key1' => 'value1', 'key2' => 'value2') }
+  it { is_expected.to run.with_params(['key1', 'value1', 'key2', 'value2']).and_return('key1' => 'value1', 'key2' => 'value2') }
 end
