@@ -1,21 +1,20 @@
 require 'spec_helper'
 
 describe 'is_numeric' do
-  
   it { is_expected.not_to eq(nil) }
 
-  it { is_expected.to run.with_params().and_raise_error(Puppet::ParseError, /wrong number of arguments/i) }
-  it { is_expected.to run.with_params(1, 2).and_raise_error(Puppet::ParseError, /wrong number of arguments/i) }
+  it { is_expected.to run.with_params.and_raise_error(Puppet::ParseError, %r{wrong number of arguments}i) }
+  it { is_expected.to run.with_params(1, 2).and_raise_error(Puppet::ParseError, %r{wrong number of arguments}i) }
 
   it { is_expected.to run.with_params(3).and_return(true) }
   it { is_expected.to run.with_params('3').and_return(true) }
   it { is_expected.to run.with_params(-3).and_return(true) }
   it { is_expected.to run.with_params('-3').and_return(true) }
-  
+
   it { is_expected.to run.with_params(3.7).and_return(true) }
   it { is_expected.to run.with_params('3.7').and_return(true) }
   it { is_expected.to run.with_params(-3.7).and_return(true) }
-  it { is_expected.to run.with_params('3.7').and_return(true) }
+  it { is_expected.to run.with_params('-3.7').and_return(true) }
 
   it { is_expected.to run.with_params('-342.2315e-12').and_return(true) }
 
@@ -28,21 +27,20 @@ describe 'is_numeric' do
   it { is_expected.to run.with_params('0001234').and_return(false) }
   it { is_expected.to run.with_params(' - 1234').and_return(false) }
 
-  context 'Checking for deprecation warning' do
-    after(:all) do
+  context 'with deprecation warning' do
+    after(:each) do
       ENV.delete('STDLIB_LOG_DEPRECATIONS')
     end
     # Checking for deprecation warning, which should only be provoked when the env variable for it is set.
-    it 'should display a single deprecation' do
-      ENV['STDLIB_LOG_DEPRECATIONS'] = "true"
+    it 'displays a single deprecation' do
+      ENV['STDLIB_LOG_DEPRECATIONS'] = 'true'
       scope.expects(:warning).with(includes('This method is deprecated'))
       is_expected.to run.with_params(7).and_return(true)
     end
-    it 'should display no warning for deprecation' do
-      ENV['STDLIB_LOG_DEPRECATIONS'] = "false"
+    it 'displays no warning for deprecation' do
+      ENV['STDLIB_LOG_DEPRECATIONS'] = 'false'
       scope.expects(:warning).with(includes('This method is deprecated')).never
       is_expected.to run.with_params(7).and_return(true)
     end
   end
-
 end
