@@ -14,7 +14,7 @@ describe 'join', :if => Puppet::Util::Package.versioncmp(Puppet.version, '5.5.0'
   it { is_expected.to run.with_params([], ':').and_return('') }
   it { is_expected.to run.with_params(['one']).and_return('one') }
   it { is_expected.to run.with_params(['one'], ':').and_return('one') }
-  it { is_expected.to run.with_params(%w[one two three]).and_return('onetwothree') }
-  it { is_expected.to run.with_params(%w[one two three], ':').and_return('one:two:three') }
-  it { is_expected.to run.with_params(%w[ōŋể ŧשợ ţђŕẽё], ':').and_return('ōŋể:ŧשợ:ţђŕẽё') }
+  it { is_expected.to run.with_params(['one', 'two', 'three']).and_return('onetwothree') }
+  it { is_expected.to run.with_params(['one', 'two', 'three'], ':').and_return('one:two:three') }
+  it { is_expected.to run.with_params(['ōŋể', 'ŧשợ', 'ţђŕẽё'], ':').and_return('ōŋể:ŧשợ:ţђŕẽё') }
 end
