@@ -10,12 +10,12 @@ describe 'prefix' do
   it { is_expected.to run.with_params('', '').and_raise_error(Puppet::ParseError, %r{expected first argument to be an Array or a Hash}) }
   it { is_expected.to run.with_params([], 2).and_raise_error(Puppet::ParseError, %r{expected second argument to be a String}) }
   it { is_expected.to run.with_params([]).and_return([]) }
-  it { is_expected.to run.with_params(['one', 2]).and_return(%w[one 2]) }
-  it { is_expected.to run.with_params(['ớņệ', 2]).and_return(%w[ớņệ 2]) }
+  it { is_expected.to run.with_params(['one', 2]).and_return(['one', '2']) }
+  it { is_expected.to run.with_params(['ớņệ', 2]).and_return(['ớņệ', '2']) }
   it { is_expected.to run.with_params([], '').and_return([]) }
   it { is_expected.to run.with_params([''], '').and_return(['']) }
   it { is_expected.to run.with_params(['one'], 'pre').and_return(['preone']) }
-  it { is_expected.to run.with_params(%w[one two three], 'pre').and_return(%w[preone pretwo prethree]) }
+  it { is_expected.to run.with_params(['one', 'two', 'three'], 'pre').and_return(['preone', 'pretwo', 'prethree']) }
   it { is_expected.to run.with_params({}).and_return({}) }
   it { is_expected.to run.with_params('key1' => 'value1', 2 => 3).and_return('key1' => 'value1', '2' => 3) }
   it { is_expected.to run.with_params({}, '').and_return({}) }
