@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe 'round' do
+describe 'round', :if => Puppet::Util::Package.versioncmp(Puppet.version, '6.0.0') < 0 do
   it { is_expected.not_to eq(nil) }
   it { is_expected.to run.with_params(34.3).and_return(34) }
   it { is_expected.to run.with_params(-34.3).and_return(-34) }
