@@ -15,7 +15,7 @@ describe 'shell_split' do
 
   describe 'shell line spliting' do
     it { is_expected.to run.with_params('foo').and_return(['foo']) }
-    it { is_expected.to run.with_params('foo bar').and_return(%w[foo bar]) }
+    it { is_expected.to run.with_params('foo bar').and_return(['foo', 'bar']) }
     it {
       is_expected.to run.with_params('\~\`\!@\#\$\%\^\&\*\(\)_\+-\=\[\]\\\\\{\}\|\;\\\':\",./\<\>\?')
                         .and_return(['~`!@#$%^&*()_+-=[]\{}|;\':",./<>?'])
@@ -26,7 +26,7 @@ describe 'shell_split' do
     }
 
     context 'with UTF8 and double byte characters' do
-      it { is_expected.to run.with_params('\\μ\\ť\\ƒ 8 \\ŧ\\ĕ\\χ\\ť').and_return(%w[μťƒ 8 ŧĕχť]) }
+      it { is_expected.to run.with_params('\\μ\\ť\\ƒ 8 \\ŧ\\ĕ\\χ\\ť').and_return(['μťƒ', '8', 'ŧĕχť']) }
       it { is_expected.to run.with_params('\\ス\\ペ\\ー \\ス\\を\\含\\む\\テ \\ \\キ\\ス\\ト').and_return(['スペー', 'スを含むテ', ' キスト']) }
     end
   end
