@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-describe 'sort' do
+describe 'sort', :if => Puppet::Util::Package.versioncmp(Puppet.version, '6.0.0') < 0 do
   describe 'signature validation' do
     it { is_expected.not_to eq(nil) }
     it { is_expected.to run.with_params.and_raise_error(Puppet::ParseError, %r{wrong number of arguments}i) }
@@ -22,7 +22,7 @@ describe 'sort' do
   context 'when called with an array' do
     it { is_expected.to run.with_params([]).and_return([]) }
     it { is_expected.to run.with_params(['a']).and_return(['a']) }
-    it { is_expected.to run.with_params(%w[c b a]).and_return(%w[a b c]) }
+    it { is_expected.to run.with_params(['c', 'b', 'a']).and_return(['a', 'b', 'c']) }
   end
 
   context 'when called with a string' do
