@@ -10,11 +10,11 @@ describe 'suffix' do
   it { is_expected.to run.with_params('', '').and_raise_error(Puppet::ParseError, %r{expected first argument to be an Array}) }
   it { is_expected.to run.with_params([], 2).and_raise_error(Puppet::ParseError, %r{expected second argument to be a String}) }
   it { is_expected.to run.with_params([]).and_return([]) }
-  it { is_expected.to run.with_params(['one', 2]).and_return(%w[one 2]) }
+  it { is_expected.to run.with_params(['one', 2]).and_return(['one', '2']) }
   it { is_expected.to run.with_params([], '').and_return([]) }
   it { is_expected.to run.with_params([''], '').and_return(['']) }
   it { is_expected.to run.with_params(['one'], 'post').and_return(['onepost']) }
-  it { is_expected.to run.with_params(%w[one two three], 'post').and_return(%w[onepost twopost threepost]) }
+  it { is_expected.to run.with_params(['one', 'two', 'three'], 'post').and_return(['onepost', 'twopost', 'threepost']) }
   it { is_expected.to run.with_params(['ỗńέ', 'ťשׂǿ', 'ŧҺř℮ə'], 'рổŝţ').and_return(['ỗńέрổŝţ', 'ťשׂǿрổŝţ', 'ŧҺř℮əрổŝţ']) }
 
   it {
