@@ -7,11 +7,11 @@ describe 'to_json' do
   it { is_expected.to run.with_params('one').and_return('"one"') }
   it { is_expected.to run.with_params([]).and_return('[]') }
   it { is_expected.to run.with_params(['one']).and_return('["one"]') }
-  it { is_expected.to run.with_params(%w[one two]).and_return('["one","two"]') }
+  it { is_expected.to run.with_params(['one', 'two']).and_return('["one","two"]') }
   it { is_expected.to run.with_params({}).and_return('{}') }
   it { is_expected.to run.with_params('key' => 'value').and_return('{"key":"value"}') }
   it {
-    is_expected.to run.with_params('one' => { 'oneA' => 'A', 'oneB' => { 'oneB1' => '1', 'oneB2' => '2' } }, 'two' => %w[twoA twoB])
+    is_expected.to run.with_params('one' => { 'oneA' => 'A', 'oneB' => { 'oneB1' => '1', 'oneB2' => '2' } }, 'two' => ['twoA', 'twoB'])
                       .and_return('{"one":{"oneA":"A","oneB":{"oneB1":"1","oneB2":"2"}},"two":["twoA","twoB"]}')
   }
 
