@@ -1,6 +1,6 @@
 require 'spec_helper'
 
-if ENV["FUTURE_PARSER"] == 'yes'
+if ENV['FUTURE_PARSER'] == 'yes'
   describe 'type_of' do
     pending 'teach rspec-puppet to load future-only functions under 3.7.5' do
       it { is_expected.not_to eq(nil) }
@@ -11,7 +11,7 @@ end
 if Puppet.version.to_f >= 4.0
   describe 'type_of' do
     it { is_expected.not_to eq(nil) }
-    it { is_expected.to run.with_params().and_raise_error(ArgumentError) }
+    it { is_expected.to run.with_params.and_raise_error(ArgumentError) }
     it { is_expected.to run.with_params('', '').and_raise_error(ArgumentError) }
 
     it 'gives the type of a string' do
