@@ -1,3 +1,4 @@
+
 require 'puppetlabs_spec_helper/module_spec_helper'
 require 'rspec-puppet-facts'
 
@@ -9,12 +10,10 @@ end
 
 include RspecPuppetFacts
 
-# rubocop:disable Style/HashSyntax
 default_facts = {
   puppetversion: Puppet.version,
   facterversion: Facter.version,
 }
-# rubocop:enable Style/HashSyntax
 
 default_facts_path = File.expand_path(File.join(File.dirname(__FILE__), 'default_facts.yml'))
 default_module_facts_path = File.expand_path(File.join(File.dirname(__FILE__), 'default_module_facts.yml'))
@@ -29,4 +28,9 @@ end
 
 RSpec.configure do |c|
   c.default_facts = default_facts
+  c.before :each do
+    # set to strictest setting for testing
+    # by default Puppet runs at warning level
+    Puppet.settings[:strict] = :warning
+  end
 end
