@@ -3,11 +3,7 @@ require 'spec_helper'
 if Puppet::Util::Package.versioncmp(Puppet.version, '4.5.0') >= 0
   describe 'Stdlib::Fqdn' do
     describe 'valid handling' do
-      %w[
-        example
-        example.com
-        www.example.com
-      ].each do |value|
+      ['example', 'example.com', 'www.example.com'].each do |value|
         describe value.inspect do
           it { is_expected.to allow_value(value) }
         end
