@@ -3,13 +3,7 @@ require 'spec_helper'
 if Puppet::Util::Package.versioncmp(Puppet.version, '4.5.0') >= 0
   describe 'Stdlib::HTTPSUrl' do
     describe 'valid handling' do
-      %w[
-        https://hello.com
-        https://notcreative.org
-        https://notexciting.co.uk
-        https://graphemica.com/❤
-        https://graphemica.com/緩
-      ].each do |value|
+      ['https://hello.com', 'https://notcreative.org', 'https://notexciting.co.uk', 'https://graphemica.com/❤', 'https://graphemica.com/緩', 'HTTPS://FOO.com'].each do |value|
         describe value.inspect do
           it { is_expected.to allow_value(value) }
         end
